/*= NEUTRIK RT-1M Audio Test System =========================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __ntrt1m_HEADER
#define __ntrt1m_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)
#define ntrt1m_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define ntrt1m_WARNING_NAN_RETURNED             (VI_WARNING_INSTR_OFFSET + 0xF1L)
#define ntrt1m_ERROR_NO_TRIGGER_DETECTED        (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define ntrt1m_ERROR_OVERFLOW_AT_INPUT          (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define ntrt1m_SYSTEM_ERROR                     (VI_ERROR_INSTR_OFFSET + 0xF4L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC ntrt1m_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC ntrt1m_simpleMeas (ViSession instrumentHandle,
                    ViInt16 selectChannel, ViReal64 inputRange, ViReal64 outputLevel,
                    ViBoolean preferredUnit, ViInt16 activeSignal, ViInt16 dataType,
                    ViPInt16 numberofBinsQueried, ViInt16 _VI_FAR binNumber[],
                    ViReal64 _VI_FAR amplitude[], ViChar _VI_FAR unit[]);
ViStatus _VI_FUNC ntrt1m_configInputMode (ViSession instrumentHandle,
                    ViBoolean inputConnection, ViBoolean CH1InternalLink,
                    ViBoolean CH2InternalLink, ViInt16 synchronizationMode,
                    ViInt16 softwareWeightingFilter, ViBoolean deemphasisFilter);
ViStatus _VI_FUNC ntrt1m_configInputRange (ViSession instrumentHandle,
                    ViInt16 input, ViReal64 inputRange, ViBoolean inputUnit);
ViStatus _VI_FUNC ntrt1m_configOutputMode (ViSession instrumentHandle,
                    ViBoolean floatGroundMode, ViBoolean channel1Mute,
                    ViBoolean channel2Mute);
ViStatus _VI_FUNC ntrt1m_configOutputLevel (ViSession instrumentHandle,
                    ViInt16 output, ViReal64 outputLevel, ViBoolean outputUnit);
ViStatus _VI_FUNC ntrt1m_configMeasUnit (ViSession instrumentHandle,
                    ViInt16 configure, ViInt16 levelUnit, ViBoolean distortionUnit,
                    ViBoolean noiseUnit, ViBoolean phaseUnit, ViReal64 phaseScale,
                    ViBoolean crosstalk);
ViStatus _VI_FUNC ntrt1m_configMtone (ViSession instrumentHandle,
                    ViInt16 activeSignal, ViReal64 pretriggerLengthms,
                    ViReal64 multitoneBurstLengthms);
ViStatus _VI_FUNC ntrt1m_defineMtoneSignal (ViSession instrumentHandle,
                    ViInt16 signalNumber, ViChar _VI_FAR signalName[],
                    ViInt16 numberofSamples, ViInt16 numberofBinsinCH1,
                    ViInt16 _VI_FAR CH1BinFreqHz[], ViReal64 _VI_FAR CH1BinPhase[],
                    ViInt16 numberofBinsinCH2, ViInt16 _VI_FAR CH2BinFreqHz[],
                    ViReal64 _VI_FAR CH2BinPhase[]);
ViStatus _VI_FUNC ntrt1m_startActiveMtone (ViSession instrumentHandle);
ViStatus _VI_FUNC ntrt1m_contActiveMtone (ViSession instrumentHandle);
ViStatus _VI_FUNC ntrt1m_readMeas (ViSession instrumentHandle,
                    ViInt16 selectChannel, ViInt16 dataType, 
                    ViPInt16 numberofBinsQueried, ViInt16 _VI_FAR binNumber[],
                    ViReal64 _VI_FAR amplitude[], ViChar _VI_FAR unit[]);
ViStatus _VI_FUNC ntrt1m_writeInstrData (ViSession instrumentHandle,
                    ViString writeBuffer);
ViStatus _VI_FUNC ntrt1m_readInstrData (ViSession instrumentHandle,
                    ViInt32 numberBytesToRead, ViChar _VI_FAR readBuffer[],
                    ViPInt32 numBytesRead);
ViStatus _VI_FUNC ntrt1m_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC ntrt1m_selfTest (ViSession instrumentHandle,
                    ViPInt16 selfTestResult, ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC ntrt1m_errorQuery (ViSession instrumentHandle, ViPInt32 errorCode,
                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC ntrt1m_errorMessage (ViSession instrumentHandle,
                    ViStatus errorCode, ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC ntrt1m_revisionQuery (ViSession instrumentHandle,
                    ViChar _VI_FAR instrumentDriverRevision[],
                    ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC ntrt1m_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
