#include <ansi_c.h>
#include <formatio.h>
#include <stdlib.h>
#include "ntrt1m.h"
#include "ntrt1mu.h"
#include <userint.h>        
/* Needed if linking in external compiler; harmless otherwise */
#include <cvirte.h>

/*= ntrt1m ================================================================*/
/* LabWindows Instrument Driver                                            */
/* Modification History:                                                   */
/*                                                                         */
/*         March 1996:   The declarations of the following arrays were     */
/*                       changed in the configPanel function so their      */
/*                       size is now 32 as opposed to 31.                  */
/*						   	short binNumber, bin[32];                      */
/*                          double amplitude[32];                          */ 
/*						 Modified by: K.S., National Instruments           */
/*=========================================================================*/

/*======================== Global Variabe Definition ========================*/ 
ViInt16 panelHand[5];
ViStatus uirErr;
ViInt16 uirCode;
ViInt32 instrumentHandle;

/*====================== Utility Function Declarations ======================*/ 
int abortApplication (void);

static int panel1, panel2, panel3, panelMain;

/*****************************************************************************/
/*=== Begin UIR SOURCE CODE =================================================*/
/*****************************************************************************/

int main (int argc, char *argv[])
{
    if (InitCVIRTE (0, argv, 0) == 0)   /* Needed if linking in external compiler; 
                                       harmless otherwise */
        return -1;  /* out of memory */
    if ((panelHand[PANEL_MAIN] = LoadPanel (0, "ntrt1mu.uir", PANEL_MAIN)) < 0)
        return -1;
    if ((panelHand[PANEL_3] = LoadPanel (panelHand[PANEL_MAIN], "ntrt1mu.uir", 
            PANEL_3)) < 0)
        return -1;
    if ((panelHand[PANEL_2] = LoadPanel (panelHand[PANEL_MAIN], "ntrt1mu.uir",  
            PANEL_2)) < 0)
        return -1;
    if ((panelHand[PANEL_1] = LoadPanel (panelHand[PANEL_MAIN], "ntrt1mu.uir",  
            PANEL_1)) < 0)
        return -1;
        
    DisplayPanel (panelHand[PANEL_MAIN]);
    DisplayPanel (panelHand[PANEL_1]);
    uirCode = RunUserInterface ();
    return 0;
}

/*****************************************************************************/ 
int CVICALLBACK initPanel (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    int IDQuery, reset;
    ViChar resourceName[256];  
    
    switch (event) {
        case EVENT_COMMIT:
            switch (control) {
                case PANEL_1_CONTINUE:
                    SetCtrlVal (panelHand[PANEL_1], PANEL_1_CONTINUE, 1);
                    GetCtrlVal (panelHand[PANEL_1], PANEL_1_RESOURCE_NAME, resourceName);
                    GetCtrlVal (panelHand[PANEL_1], PANEL_1_ID_QUERY, &IDQuery);
                    GetCtrlVal (panelHand[PANEL_1], PANEL_1_RESET_DEVICE, &reset);
            
                    if ((uirErr = ntrt1m_init (resourceName , IDQuery, reset, &instrumentHandle))<0)
                        abortApplication ();
            
                    DisplayPanel (panelHand[PANEL_2]);
                break;
            }   
            break;
        case EVENT_RIGHT_CLICK:
            switch (control) {
                case PANEL_1_RESOURCE_NAME:
                    MessagePopup ("Control Help",
                        "Specifies the interface and address of the device.\n\n"
                        "Interface Grammar:\n GPIB[board]::primary address[::secondary "
                        "address][::INSTR]");
                    break;
                case PANEL_1_ID_QUERY:
                    MessagePopup ("Control Help",
                        "Specifies if an ID Query is sent to the instrument\n during the "
                        "initialization procedure.\n\nValid Range:\nVI_OFF (0) - Skip "
                        "Query\nVI_ON  (1) - Do Query (Default Value)");
                    break;
                case PANEL_1_RESET_DEVICE:
                    MessagePopup ("Control Help",
                        "Specifies if the instrument is to be reset to its\n"
                        "power-on settings during the initialization procedure.\n\n"
                        "Valid Range:\n"
                        "VI_OFF (0) - Don't Reset\n"
                        "VI_ON  (1) - Reset Device (Default Value)");
                    break;
                case PANEL_1_CONTINUE:
                    MessagePopup ("Control Help",  "Executes the Instrument Initialization "
                        "and if successful opens the next panel.");
                    break;
            }   
    }
    return 0;
}

/*****************************************************************************/ 
int CVICALLBACK configPanel (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    int variable, resultType, resultSource, circuit;
    int front, channel, link, prefUnit, signal, data, i;
    double input, output;
    short binNumber, bin[32];
    double amplitude[32];
    char unit[10];
    int plotHdl;
	char * measType[] = {"Level Measurement","Distortion Measurement", "Noise Measurement"};
    
    switch (event) {
        case EVENT_COMMIT:
            switch (control) {
                case PANEL_2_CONTINUE_3:
                    SetCtrlVal (panelHand[PANEL_2], PANEL_2_CONTINUE_3, 1);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_FRONT, &front);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_CHANNEL, &channel);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_LINK, &link);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_INPUT, &input);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_OUTPUT, &output);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_UNIT, &prefUnit);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_SIGNAL, &signal);
                    GetCtrlVal (panelHand[PANEL_2], PANEL_2_DATA, &data);
                    
                    if ((uirErr = ntrt1m_configInputMode (instrumentHandle, front, 
                            link, link, 0, 0, 0)) <0) 
                        abortApplication ();
                    if ((uirErr = ntrt1m_simpleMeas (instrumentHandle, channel, 
                            input, output, prefUnit, signal, data, &binNumber,
                            bin, amplitude, unit)) <0) 
                        abortApplication ();
                                            
                    DisplayPanel (panelHand[PANEL_3]);
                    
                    SetCtrlVal (panelHand[PANEL_3], PANEL_3_BINNUMBER, binNumber);
                    
					SetCtrlAttribute (panelHand[PANEL_3], PANEL_3_GRAPH, ATTR_YNAME, unit);
					SetCtrlAttribute (panelHand[PANEL_3], PANEL_3_GRAPH, ATTR_LABEL_TEXT,
									  measType[data]);
					plotHdl = PlotXY (panelHand[PANEL_3], PANEL_3_GRAPH, bin, amplitude,
									  binNumber, VAL_SHORT_INTEGER, VAL_DOUBLE,
									  VAL_VERTICAL_BAR, VAL_EMPTY_SQUARE, VAL_SOLID, 1,
									  VAL_RED);
					DeleteGraphPlot (panelHand[PANEL_3], PANEL_3_GRAPH, plotHdl,
									 VAL_DELAYED_DRAW);
               break;  
            }   
            break;
        case EVENT_RIGHT_CLICK:
            switch (control) {
                case PANEL_2_FRONT:
                    MessagePopup ("Control Help",
                        "Selects either the front or back panel connections for input to the RT-1M");
                    break;
                case PANEL_2_CHANNEL:
                    MessagePopup ("Control Help",
                        "Selects the channel source");
                    break;
                case PANEL_2_LINK:
                    MessagePopup ("Control Help",
                        "Optionally selects whether or not the input should be internally linked to the ouput");
                    break;
                case PANEL_2_INPUT:
                    MessagePopup ("Control Help", "Input level range depends on selected units\n"
                        "Valid Range:\n -60   to +20 dBVp \n 0.001 to  10 Vp");
                    break;
                case PANEL_2_CONTINUE_3:
                    MessagePopup ("Control Help",
                        "Configures the instrument and takes the selected measurement.\n"
                        "Continue on to the next panel.");
                    break;
                case PANEL_2_OUTPUT:
                    MessagePopup ("Control Help", "Output level range depends on selected units\n"
                        "Valid Range:\n\n -60   to +20  dBVp \n 0.001 to  10  Vp");
                    break;
                case PANEL_2_UNIT:
                    MessagePopup ("Control Help", "Selects the desired units for measurment");
                    break;
                case PANEL_2_SIGNAL:
                    MessagePopup ("Control Help", "Selects the signal source");
                    break;
                case PANEL_2_DATA:
                    MessagePopup ("Control Help", "Selects the measurement type to perform");
                    break;
            }   
    }
    return 0;
}

/*****************************************************************************/ 
int CVICALLBACK displayPanel (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_COMMIT:

            break;
        case EVENT_RIGHT_CLICK:
            switch (control) {
                case PANEL_3_BINNUMBER:
                    MessagePopup ("Control Help", "Displays the variable read from the "
                        "instrument.");
                    break;
                case PANEL_3_GRAPH:
                    MessagePopup ("Control Help", "Displays the limit code read from the "
                        "instrument.");
                    break;
            }   
    }
    return 0;
}

/*****************************************************************************/ 
int CVICALLBACK Quit (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_COMMIT:
            if ((ConfirmPopup ("Exit Application", "Would you like to exit this "
                    "application?")) == 1) {
                if ((uirErr = ntrt1m_close (instrumentHandle)) <0 )
                    abortApplication ();
                QuitUserInterface (uirCode);
            }
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Control Help",
                  "Closes this session with instrument and closes the "
                  "application.");
            break;
    }
    return 0;
}

/*****************************************************************************/ 
int CVICALLBACK Back (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_COMMIT:
            SetCtrlVal (panelHand[PANEL_2], PANEL_2_CONTINUE_3, 0);
            DisplayPanel (panelHand[PANEL_2]);
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Control Help",
                  "Switches the application to the configuration panel.");
            break;
    }
    return 0;
}

/*****************************************************************************/ 
int CVICALLBACK Cancel (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_COMMIT:
            if ((ConfirmPopup ("Exit Application", "Would you like to exit this "
                   "application?")) == 1) {
                QuitUserInterface (uirCode);
            }
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Control Help",
                  "Closes this session with instrument and closes the application.");
            break;
    }
    return 0;
}

/*****************************************************************************/ 
int abortApplication (void)
{
    ViChar errorMessage[256], errBuffer[256];
    ViInt16 response;

    SetWaitCursor (0);
    ntrt1m_errorMessage(VI_NULL, uirErr, errorMessage);
    Fmt (errBuffer,"%s<The following error caused the application to fail:\n\n%s\n\n"
        "Attempting to Close Instrument Driver and Exit Application", 
        errorMessage);
    MessagePopup("ERROR!, Application Failed", errBuffer);
    
    if ((uirErr = ntrt1m_close (instrumentHandle)) < 0) {
        ntrt1m_errorMessage(VI_NULL, uirErr, errorMessage);
        Fmt (errBuffer, "%s<Application failed to close the Instrument Driver.\n\n"
            "%s\n\nExiting Application.", errorMessage);
        MessagePopup("ERROR!",errBuffer);
    }
    else 
        MessagePopup("Application Aborted","Instrument Driver Closed, Exiting Application.");
        
    QuitUserInterface (uirCode);
    exit (-1);
    
    return 0;
}

/*****************************************************************************/ 
void CVICALLBACK PanelHelp (int menuBar, int menuItem, void *callbackData,
        int panel)
{
    if (GetActivePanel () == (panelHand[PANEL_1])) MessagePopup ("Panel Help",
                "This panel opens a session with the instrument.\n"
                "Performs an identification query on the instrument\n"
                "Resets the instrument to a known state.\n\n"
                "NOTE: This instrument driver requires that the rear panel \n"
                "switches F1 & F2 are both turned to the \"OFF\" position. The \n"
                "driver uses the Line-feed character \"\\n\" as the command \n"
                "terminator and will not operate correctly if the instrument is \n"
                "not configured properly.");
    if (GetActivePanel () == (panelHand[PANEL_2])) MessagePopup ("Panel Help",
                "This panel sets and configures the instrument,\n"
                "and reads data from the instrument.");
    if (GetActivePanel () == (panelHand[PANEL_3])) MessagePopup ("Panel Help",
                "This panel displays the data read from the instrument.");
    if (GetActivePanel () == (panelHand[PANEL_MAIN])) MessagePopup ("Panel Help",
                "This is a simple demo program using the ntrt1m instrument driver.\n"
                "It initializes and optionally resets the instrument to a known state.\n"
                "It then configures the instrument, and reads data back from it.\n");
}

/*****************************************************************************/
/*=== END UIR SOURCE CODE ===================================================*/
/*****************************************************************************/
